==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/id/gregorian.js <==
define(
//begin v1.x content
{
	"dayPeriods-standAlone-abbr-noon": "tengah hari",
	"field-tue-relative+-1": "Selasa lalu",
	"field-year": "Tahun",
	"dateFormatItem-yw": "'minggu' 'ke'-w y",
	"dayPeriods-format-abbr-afternoon1": "siang",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-ms": "mm.ss",
	"timeFormat-short": "HH.mm",
	"field-minute": "Menit",
	"field-tue-narrow-relative+0": "Sel. ini",
	"field-tue-narrow-relative+1": "Sel. berikutnya",
	"field-thu-short-relative+0": "Kam. ini",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "hari ini",
	"field-thu-short-relative+1": "Kam. berikutnya",
	"field-day-relative+1": "besok",
	"field-day-relative+2": "lusa",
	"field-wed-narrow-relative+-1": "Rab. lalu",
	"field-year-narrow": "thn.",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dayPeriods-format-narrow-am": "AM",
	"field-second-short": "dtk.",
	"dayPeriods-standAlone-abbr-morning1": "pagi",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-narrow-morning1": "pagi",
	"dayPeriods-format-abbr-am": "AM",
	"field-month-relative+0": "bulan ini",
	"field-week-relative+0": "minggu ini",
	"field-month-relative+1": "Bulan berikutnya",
	"timeFormat-medium": "HH.mm.ss",
	"field-week-relative+1": "minggu depan",
	"field-sun-narrow-relative+0": "Min. ini",
	"field-mon-short-relative+0": "Sen. ini",
	"field-sun-narrow-relative+1": "Min. berikutnya",
	"field-mon-short-relative+1": "Sen. berikutnya",
	"field-second-relative+0": "sekarang",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-standAlone-wide-noon": "tengah hari",
	"eraNames": [
		"Sebelum Masehi",
		"Masehi"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"field-month-short": "bln.",
	"field-day": "Hari",
	"dayPeriods-standAlone-wide-night1": "malam",
	"field-year-relative+-1": "tahun lalu",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "Sab. lalu",
	"dayPeriods-format-narrow-afternoon1": "siang",
	"dayPeriods-format-wide-afternoon1": "siang",
	"field-hour-relative+0": "jam ini",
	"field-wed-relative+-1": "Rabu lalu",
	"dateTimeFormat-medium": "{1} {0}",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dayPeriods-standAlone-narrow-noon": "tengah hari",
	"field-sat-narrow-relative+-1": "Sab. lalu",
	"field-second": "Detik",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d MMMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dayPeriods-standAlone-abbr-midnight": "tengah malam",
	"field-quarter": "Kuartal",
	"field-week-short": "mgg.",
	"dayPeriods-format-narrow-midnight": "tengah malam",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dayPeriods-format-wide-evening1": "sore",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "Sel. ini",
	"field-tue-short-relative+1": "Sel. berikutnya",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "Bulan",
	"dayPeriods-standAlone-abbr-night1": "malam",
	"field-day-narrow": "h",
	"dayPeriods-standAlone-narrow-afternoon1": "siang",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "mnt.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "Sab. ini",
	"field-sat-short-relative+1": "Sab. berikutnya",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "d MMM y",
	"eraAbbr": [
		"SM",
		"M"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-second-narrow": "d",
	"dayPeriods-standAlone-narrow-night1": "malam",
	"field-mon-relative+0": "Senin ini",
	"field-year-short": "thn.",
	"field-mon-relative+1": "Senin berikutnya",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-format-wide-morning1": "pagi",
	"field-quarter-relative+-1": "Kuartal lalu",
	"dayPeriods-standAlone-narrow-am": "AM",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "Jam",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dayPeriods-format-wide-night1": "malam",
	"dateFormat-full": "EEEE, dd MMMM y",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "krtl.",
	"field-sat-narrow-relative+0": "Sab. ini",
	"dateFormatItem-Hmv": "HH.mm v",
	"field-fri-relative+0": "Jumat ini",
	"field-sat-narrow-relative+1": "Sab. berikutnya",
	"field-fri-relative+1": "Jumat berikutnya",
	"dayPeriods-format-narrow-noon": "tengah hari",
	"field-sun-short-relative+0": "Min. ini",
	"field-sun-short-relative+1": "Min. berikutnya",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-Ehm": "E h.mm a",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"dayPeriods-format-wide-midnight": "tengah malam",
	"field-quarter-relative+0": "Kuartal ini",
	"timeFormat-long": "HH.mm.ss z",
	"field-minute-relative+0": "menit ini",
	"field-quarter-relative+1": "Kuartal berikutnya",
	"field-wed-short-relative+-1": "Rab. lalu",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "dd/MM/yy",
	"dayPeriods-format-abbr-night1": "malam",
	"dateFormatItem-MMMMW": "'minggu' 'ke'-W MMM",
	"field-thu-short-relative+-1": "Kam. lalu",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-mon-narrow-relative+-1": "Sen. lalu",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "Kam. lalu",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-tue-narrow-relative+-1": "Sel. lalu",
	"dayPeriods-format-abbr-evening1": "sore",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"field-wed-short-relative+0": "Rab. ini",
	"field-wed-short-relative+1": "Rab. berikutnya",
	"dateFormatItem-Hmsv": "HH.mm.ss v",
	"field-sun-relative+-1": "hari Minggu lalu",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Hari dalam Seminggu",
	"dayPeriods-standAlone-wide-evening1": "sore",
	"field-sat-relative+0": "Sabtu ini",
	"dateFormatItem-h": "h a",
	"field-sat-relative+1": "Sabtu berikutnya",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"dateFormatItem-hmsv": "h.mm.ss. a v",
	"dayPeriods-format-abbr-morning1": "pagi",
	"dayPeriods-standAlone-narrow-evening1": "sore",
	"timeFormat-full": "HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "Kam. ini",
	"field-sun-narrow-relative+-1": "Min. lalu",
	"field-mon-short-relative+-1": "Sen. lalu",
	"field-thu-narrow-relative+1": "Kam. berikutnya",
	"field-thu-relative+0": "Kamis ini",
	"dayPeriods-standAlone-abbr-afternoon1": "siang",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "Jum. lalu",
	"dateFormatItem-hmv": "h.mm a v",
	"dayPeriods-format-abbr-noon": "tengah hari",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-yMd": "d/M/y",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "Minggu",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "Rab. ini",
	"field-wed-narrow-relative+1": "Rab. berikutnya",
	"dayPeriods-standAlone-wide-morning1": "pagi",
	"field-fri-short-relative+0": "Jum. ini",
	"field-fri-short-relative+1": "Jum. berikutnya",
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dayPeriods-standAlone-narrow-morning1": "pagi",
	"dayPeriods-format-abbr-midnight": "tengah malam",
	"field-hour-short": "jam",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "bln.",
	"field-hour-narrow": "j",
	"field-fri-narrow-relative+-1": "Jum. lalu",
	"field-year-relative+0": "tahun ini",
	"field-year-relative+1": "tahun depan",
	"field-fri-relative+-1": "Jumat lalu",
	"eraNarrow": [
		"SM",
		"M"
	],
	"dayPeriods-format-wide-noon": "tengah hari",
	"field-tue-short-relative+-1": "Sel. lalu",
	"field-minute-narrow": "m",
	"dayPeriods-standAlone-wide-afternoon1": "siang",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-mon-narrow-relative+0": "Sen. ini",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-narrow-relative+1": "Sen. berikutnya",
	"dayPeriods-standAlone-wide-midnight": "tengah malam",
	"dateFormatItem-yM": "M/y",
	"field-zone": "Zona Waktu",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E, d MMM",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"dateFormatItem-yMEd": "E, d/M/y",
	"dayPeriods-standAlone-narrow-midnight": "tengah malam",
	"field-quarter-narrow": "krtl.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "kemarin",
	"field-sun-short-relative+-1": "Min. lalu",
	"field-day-relative+-2": "kemarin dulu",
	"dayPeriods-format-narrow-night1": "malam",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"field-sun-relative+0": "hari Minggu ini",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-Gy": "y G",
	"field-era": "Era",
	"field-week-narrow": "mgg.",
	"field-day-short": "h",
	"dayPeriods-standAlone-abbr-evening1": "sore",
	"field-fri-narrow-relative+0": "Jum. ini",
	"dayPeriods-format-narrow-evening1": "sore",
	"field-fri-narrow-relative+1": "Jum. berikutnya",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/id/gregorian.js <==
define(
//begin v1.x content
{
	"dayPeriods-standAlone-abbr-noon": "tengah hari",
	"field-tue-relative+-1": "Selasa lalu",
	"field-year": "tahun",
	"dateFormatItem-yw": "'minggu' 'ke'-w Y",
	"dayPeriods-format-abbr-afternoon1": "siang",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-ms": "mm.ss",
	"timeFormat-short": "HH.mm",
	"field-minute": "menit",
	"field-month-narrow-relative+-1": "bln lalu",
	"field-tue-narrow-relative+0": "Sel. ini",
	"field-tue-narrow-relative+1": "Sel. berikutnya",
	"field-thu-short-relative+0": "Kam. ini",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "hari ini",
	"field-thu-short-relative+1": "Kam. berikutnya",
	"field-day-relative+1": "besok",
	"field-week-narrow-relative+0": "mgg ini",
	"field-day-relative+2": "lusa",
	"field-week-narrow-relative+1": "mgg depan",
	"dateFormatItem-EBhms": "E h.mm.ss B",
	"field-wed-narrow-relative+-1": "Rab. lalu",
	"field-year-narrow": "thn.",
	"field-era-short": "era",
	"field-year-narrow-relative+0": "thn ini",
	"field-tue-relative+0": "Selasa ini",
	"field-year-narrow-relative+1": "thn depan",
	"field-tue-relative+1": "Selasa berikutnya",
	"dayPeriods-format-narrow-am": "AM",
	"field-weekdayOfMonth": "hari kerja",
	"field-second-short": "dtk.",
	"dayPeriods-standAlone-abbr-morning1": "pagi",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-narrow-morning1": "pagi",
	"field-weekdayOfMonth-narrow": "hr kerja",
	"dayPeriods-format-abbr-am": "AM",
	"field-month-relative+0": "bulan ini",
	"field-week-relative+0": "minggu ini",
	"timeFormat-medium": "HH.mm.ss",
	"field-month-relative+1": "bulan berikutnya",
	"field-week-relative+1": "minggu depan",
	"field-sun-narrow-relative+0": "Min. ini",
	"field-mon-short-relative+0": "Sen. ini",
	"field-sun-narrow-relative+1": "Min. berikutnya",
	"field-mon-short-relative+1": "Sen. berikutnya",
	"field-second-relative+0": "sekarang",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-standAlone-wide-noon": "tengah hari",
	"eraNames": [
		"Sebelum Masehi",
		"Masehi"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"field-weekOfMonth": "minggu",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"field-month-short": "bln.",
	"field-day": "hari",
	"dayPeriods-standAlone-wide-night1": "malam",
	"field-year-relative+-1": "tahun lalu",
	"field-dayOfYear-short": "hari dlm setahun",
	"dayPeriods-format-wide-am": "AM",
	"field-sat-short-relative+-1": "Sab. lalu",
	"dayPeriods-format-narrow-afternoon1": "siang",
	"dayPeriods-format-wide-afternoon1": "siang",
	"field-hour-relative+0": "jam ini",
	"field-wed-relative+-1": "Rabu lalu",
	"dateTimeFormat-medium": "{1} {0}",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dayPeriods-standAlone-narrow-noon": "tengah hari",
	"field-sat-narrow-relative+-1": "Sab. lalu",
	"field-second": "detik",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-Ehms": "E h.mm.ss a",
	"dateFormat-long": "d MMMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dayPeriods-standAlone-abbr-midnight": "tengah malam",
	"field-quarter": "kuartal",
	"field-week-short": "mgg.",
	"dayPeriods-format-narrow-midnight": "tengah malam",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-day-narrow-relative+2": "lusa",
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dayPeriods-format-wide-evening1": "sore",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-tue-short-relative+0": "Sel. ini",
	"field-tue-short-relative+1": "Sel. berikutnya",
	"field-month-short-relative+-1": "bln lalu",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "bulan",
	"dayPeriods-standAlone-abbr-night1": "malam",
	"field-day-narrow": "h",
	"dayPeriods-standAlone-narrow-afternoon1": "siang",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "mnt.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "Sab. ini",
	"field-sat-short-relative+1": "Sab. berikutnya",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormat-medium": "d MMM y",
	"eraAbbr": [
		"SM",
		"M"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dayPeriods-format-abbr-pm": "PM",
	"field-second-narrow": "d",
	"dayPeriods-standAlone-narrow-night1": "malam",
	"field-mon-relative+0": "Senin ini",
	"field-year-short": "thn.",
	"field-mon-relative+1": "Senin berikutnya",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"dayPeriods-format-wide-morning1": "pagi",
	"field-quarter-relative+-1": "Kuartal lalu",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-dayperiod-narrow": "AM/PM",
	"field-week-narrow-relative+-1": "mgg lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dayPeriods-format-wide-pm": "PM",
	"field-dayOfYear": "hari dalam setahun",
	"field-sat-relative+-1": "Sabtu lalu",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d/M",
	"field-hour": "Jam",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dayPeriods-format-wide-night1": "malam",
	"dateFormat-full": "EEEE, dd MMMM y",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "krtl.",
	"field-sat-narrow-relative+0": "Sab. ini",
	"dateFormatItem-Hmv": "HH.mm v",
	"field-fri-relative+0": "Jumat ini",
	"field-sat-narrow-relative+1": "Sab. berikutnya",
	"field-fri-relative+1": "Jumat berikutnya",
	"dateFormatItem-EBhm": "E h.mm B",
	"field-month-narrow-relative+0": "bln ini",
	"field-month-narrow-relative+1": "bln berikutnya",
	"dayPeriods-format-narrow-noon": "tengah hari",
	"field-sun-short-relative+0": "Min. ini",
	"field-sun-short-relative+1": "Min. berikutnya",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-Ehm": "E h.mm a",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agu",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"dayPeriods-format-wide-midnight": "tengah malam",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+0": "kuartal ini",
	"field-minute-relative+0": "menit ini",
	"field-quarter-relative+1": "kuartal berikutnya",
	"field-wed-short-relative+-1": "Rab. lalu",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "dd/MM/yy",
	"dateFormatItem-Bh": "h B",
	"dayPeriods-format-abbr-night1": "malam",
	"dateFormatItem-MMMMW": "'minggu' 'ke'-W MMMM",
	"field-year-narrow-relative+-1": "thn lalu",
	"field-thu-short-relative+-1": "Kam. lalu",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-mon-narrow-relative+-1": "Sen. lalu",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "Kam. lalu",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "HH",
	"field-weekOfMonth-short": "mgg.",
	"field-tue-narrow-relative+-1": "Sel. lalu",
	"dayPeriods-format-abbr-evening1": "sore",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"field-wed-short-relative+0": "Rab. ini",
	"field-wed-short-relative+1": "Rab. berikutnya",
	"dateFormatItem-Hmsv": "HH.mm.ss v",
	"field-sun-relative+-1": "hari Minggu lalu",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "hari dalam seminggu",
	"dayPeriods-standAlone-wide-evening1": "sore",
	"field-sat-relative+0": "Sabtu ini",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "lusa",
	"field-sat-relative+1": "Sabtu berikutnya",
	"field-week-short-relative+0": "mgg ini",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agu",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"dateFormatItem-hmsv": "h.mm.ss. a v",
	"field-week-short-relative+1": "mgg depan",
	"dayPeriods-format-abbr-morning1": "pagi",
	"dayPeriods-standAlone-narrow-evening1": "sore",
	"field-dayOfYear-narrow": "hari dlm 1 thn",
	"field-month-short-relative+0": "bln ini",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-month-short-relative+1": "bln berikutnya",
	"field-weekdayOfMonth-short": "hr kerja",
	"dateFormatItem-MEd": "E, d/M",
	"field-zone-narrow": "zona wkt",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "Kam. ini",
	"field-sun-narrow-relative+-1": "Min. lalu",
	"field-mon-short-relative+-1": "Sen. lalu",
	"field-thu-narrow-relative+1": "Kam. berikutnya",
	"field-thu-relative+0": "Kamis ini",
	"dayPeriods-standAlone-abbr-afternoon1": "siang",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "Jum. lalu",
	"dateFormatItem-hmv": "h.mm a v",
	"dayPeriods-format-abbr-noon": "tengah hari",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-yMd": "d/M/y",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-week": "minggu",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "Rab. ini",
	"field-wed-narrow-relative+1": "Rab. berikutnya",
	"dayPeriods-standAlone-wide-morning1": "pagi",
	"field-year-short-relative+0": "thn ini",
	"field-dayperiod-short": "AM/PM",
	"field-year-short-relative+1": "thn depan",
	"field-fri-short-relative+0": "Jum. ini",
	"field-fri-short-relative+1": "Jum. berikutnya",
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"field-week-short-relative+-1": "mgg lalu",
	"dayPeriods-standAlone-narrow-morning1": "pagi",
	"dayPeriods-format-abbr-midnight": "tengah malam",
	"field-hour-short": "jam",
	"field-zone-short": "zona wkt",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "bln.",
	"field-hour-narrow": "j",
	"field-fri-narrow-relative+-1": "Jum. lalu",
	"field-year-relative+0": "tahun ini",
	"field-year-relative+1": "tahun depan",
	"field-era-narrow": "era",
	"field-fri-relative+-1": "Jumat lalu",
	"eraNarrow": [
		"SM",
		"M"
	],
	"dateFormatItem-Bhms": "h.mm.ss B",
	"dayPeriods-format-wide-noon": "tengah hari",
	"field-tue-short-relative+-1": "Sel. lalu",
	"field-minute-narrow": "m",
	"dayPeriods-standAlone-wide-afternoon1": "siang",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-mon-narrow-relative+0": "Sen. ini",
	"dateFormatItem-EHm": "E HH.mm",
	"field-mon-narrow-relative+1": "Sen. berikutnya",
	"dayPeriods-standAlone-wide-midnight": "tengah malam",
	"field-year-short-relative+-1": "thn lalu",
	"dateFormatItem-yM": "M/y",
	"field-zone": "zona waktu",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-weekOfMonth-narrow": "mgg.",
	"dateFormatItem-EHms": "E HH.mm.ss",
	"dateFormatItem-yMEd": "E, d/M/y",
	"field-weekday-narrow": "hari dlm seminggu",
	"dayPeriods-standAlone-narrow-midnight": "tengah malam",
	"field-quarter-narrow": "krtl.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"field-day-relative+-1": "kemarin",
	"field-sun-short-relative+-1": "Min. lalu",
	"field-day-relative+-2": "kemarin dulu",
	"dayPeriods-format-narrow-night1": "malam",
	"field-weekday-short": "hari dlm seminggu",
	"dateFormatItem-Bhm": "h.mm B",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"field-sun-relative+0": "hari Minggu ini",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-Gy": "y G",
	"field-era": "era",
	"field-week-narrow": "mgg.",
	"field-day-short": "h",
	"dayPeriods-standAlone-abbr-evening1": "sore",
	"field-fri-narrow-relative+0": "Jum. ini",
	"dayPeriods-format-narrow-evening1": "sore",
	"field-fri-narrow-relative+1": "Jum. berikutnya",
	"dayPeriods-standAlone-wide-am": "AM"
}
//end v1.x content
);
